@@ -153,7 +153,7 @@ class Eval(PYSON):
 
     @staticmethod
     def eval(dct, context):
-        if '.' in dct['v']:
+        if '.' in dct['v'] and dct['v'] not in context:
             base, name = dct['v'].split('.', 1)
             return Eval.eval({
                     'v': name,
@@ -509,7 +509,10 @@ class In(PYSON):
 
     @staticmethod
     def eval(dct, context):
-        return dct['k'] in dct['v']
+        if dct['v']:
+            return dct['k'] in dct['v']
+        else:
+            return False
 
 
 class Date(PYSON):
